Documentation
¶
Overview ¶
SPDX-Copyright: Copyright (c) Capital One Services, LLC SPDX-License-Identifier: Apache-2.0 Copyright 2017 Capital One Services, LLC
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type EnvValues ¶
type EnvValues struct {
// Server configuration
Server struct {
Addr string
Cert string
Key string
}
// Database configuration
Db struct {
Driver string
Datasource string
}
// Default pattern customization
Pattern struct {
Default string
}
// External (user-facing) customization
Branding struct {
Name string
ShortName string
}
// Github integration
Github struct {
Email string
Url string
Client string
Secret string
Scope string
AdminOrg string
RequestsHz int
}
// Slack integration
Slack struct {
TargetUrl string
}
// Logging/debug config
Monitor struct {
LogLevel string
Sunlight bool
UaList string
LogPeriod time.Duration
DocsUrl string
}
// Caching config
Cache struct {
CacheTTL time.Duration
LongCacheTTL time.Duration
}
// Github testing config
Test struct {
GithubToken string
GithubTestEnable bool
}
// Access config
Access struct {
LimitUsers bool
LimitOrgs bool
}
Old struct {
Approvals int64
Pattern string
SelfApprovalOff bool
}
}
var Env EnvValues
Click to show internal directories.
Click to hide internal directories.