Documentation
¶
Overview ¶
SPDX-Copyright: Copyright (c) Capital One Services, LLC SPDX-License-Identifier: Apache-2.0 Copyright 2017 Capital One Services, LLC
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
SPDX-Copyright: Copyright (c) Capital One Services, LLC SPDX-License-Identifier: Apache-2.0 Copyright 2017 Capital One Services, LLC
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- type LowerSet
- func (s LowerSet) Add(key lowercase.String)
- func (s LowerSet) AddAll(input LowerSet)
- func (s LowerSet) AddAllSet(input Set)
- func (s LowerSet) AddString(key string)
- func (s LowerSet) Contains(key lowercase.String) bool
- func (s LowerSet) ContainsString(key string) bool
- func (s LowerSet) Difference(other LowerSet) LowerSet
- func (s LowerSet) Intersection(other LowerSet) LowerSet
- func (s LowerSet) Keys() lowercase.Slice
- func (s LowerSet) KeysSorted(f func(s1, s2 lowercase.String) bool) lowercase.Slice
- func (s LowerSet) MarshalJSON() ([]byte, error)
- func (s LowerSet) Print(sep string) string
- func (s LowerSet) Remove(key lowercase.String)
- func (s LowerSet) RemoveString(key string)
- func (s LowerSet) ToSet() Set
- func (s *LowerSet) UnmarshalJSON(data []byte) error
- type Set
- func (s Set) Add(key string)
- func (s Set) AddAll(input Set)
- func (s Set) Contains(key string) bool
- func (s Set) Difference(other Set) Set
- func (s Set) Intersection(other Set) Set
- func (s Set) Keys() []string
- func (s Set) KeysSorted(f func(s1, s2 string) bool) []string
- func (s Set) MarshalJSON() ([]byte, error)
- func (s Set) Print(sep string) string
- func (s Set) Remove(key string)
- func (s *Set) UnmarshalJSON(data []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LowerSet ¶
LowerSet is a collection of unique lowercase strings
func NewLowerFromString ¶
NewLowerFromString creates a new lowerset with the provided values
func (LowerSet) ContainsString ¶
ContainsString tests whether an element is a member of the lowerset
func (LowerSet) Difference ¶
Difference returns all elements that are in this lowerset but not in the passed-in lowerset
func (LowerSet) Intersection ¶
Intersection returns all elements in common between this lowerset and the lowerset passed in
func (LowerSet) KeysSorted ¶
func (LowerSet) MarshalJSON ¶
func (LowerSet) RemoveString ¶
func (*LowerSet) UnmarshalJSON ¶
type Set ¶
Set is a collection of unique strings